# CHANGELOG

### 0.1.2 - 2024-09-22
- Added MANIFEST.in
- Ensured markdown project description

### 0.1.1 - 2024-09-22
- Bug fix in setup

### 0.1.0 - 2024-09-22
- Added the `cythonpowered-benchmark` script
- Development updates

### 0.0.3 - 2024-09-10
- Update requirements

### 0.0.2 - 2024-09-10
- Bug fix in setup

### 0.0.1 - 2024-09-10
- First release
- Includes the `cythonpowered.random` module
